==> ciao-4.6-src-core.tar.gz: ciao-4.6/src/lib/datamodel/modules/pyregion/setup.py <==
# 
#  Copyright (C) 2010  Smithsonian Astrophysical Observatory
#
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License along
#  with this program; if not, write to the Free Software Foundation, Inc.,
#  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

from numpy.distutils.core import setup, Extension
from os import environ

name = '_region'

c_libs  = ['ascdm']
c_files = ['pyregion.c']

mk_top = environ.get ("MK_TOP")
dmroot = environ.get ("DMROOT")

inc1 = dmroot + '/include'
inc2 = mk_top + '/lib/region'
lib1 = dmroot + '/lib'

setup(name=name,
      version='0.1.0',
      author='Smithsonian Astrophysical Observatory / Chandra X-Ray Center',
      author_email='cxchelp@head.cfa.harvard.edu',
      py_modules=['__init__'],
      packages=['.'],
      ext_modules=[Extension(name,
                             c_files,
			     include_dirs=['./', inc1, inc2 ],
                             library_dirs=['./', lib1 ],
                             libraries=c_libs,
                             depends=['pyregion.c',],
                             ),
                   ],
     )

==> ciao-4.8-src-core.tar.gz: ciao-4.8/src/lib/datamodel/modules/pyregion/setup.py <==
# 
#  Copyright (C) 2010  Smithsonian Astrophysical Observatory
#
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License along
#  with this program; if not, write to the Free Software Foundation, Inc.,
#  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

from numpy.distutils.core import setup, Extension
from os import environ

name = '_region'

c_libs  = ['ascdm']
c_files = ['pyregion.c']

mk_top = environ.get ("MK_TOP")
dmroot = environ.get ("DMROOT")

inc1 = dmroot + '/include'
inc2 = mk_top + '/lib/region/src'
lib1 = dmroot + '/lib'

setup(name=name,
      version='0.1.0',
      author='Smithsonian Astrophysical Observatory / Chandra X-Ray Center',
      author_email='cxchelp@head.cfa.harvard.edu',
      py_modules=['__init__'],
      packages=['.'],
      ext_modules=[Extension(name,
                             c_files,
			     include_dirs=['./', inc1, inc2 ],
                             library_dirs=['./', lib1 ],
                             libraries=c_libs,
                             depends=['pyregion.c',],
                             ),
                   ],
     )
